@@ -144,26 +144,6 @@ class TestTimeUUID(BaseColumnIOTest):
     def comparator_converter(self, val):
         return val if isinstance(val, UUID) else UUID(val)
 
-class TestBooleanIO(BaseColumnIOTest):
-
-    column = columns.Boolean
-
-    pkey_val = True
-    data_val = False
-
-    def comparator_converter(self, val):
-        return val.value if isinstance(val, columns.Boolean.Quoter) else val
-
-class TestBooleanQuoter(BaseColumnIOTest):
-
-    column = columns.Boolean
-
-    pkey_val = True
-    data_val = columns.Boolean.Quoter(False)
-
-    def comparator_converter(self, val):
-        return val.value if isinstance(val, columns.Boolean.Quoter) else val
-
 class TestFloatIO(BaseColumnIOTest):
 
     column = columns.Float
